@@ -24,7 +24,7 @@
 
 IsotopeGuideView::IsotopeGuideView(QWidget *parent) : QGraphicsView(parent)
 {
-    m_guidedView = 0;
+    m_guidedView = nullptr;
     m_scale = 1.0;
 
     setCursor(Qt::OpenHandCursor);
@@ -103,4 +103,3 @@ void IsotopeGuideView::setZoomLevel(double zoomLevel)
     m_zoomLevel = zoomLevel;
 }
 
-#include "isotopeguideview.moc"
