@@ -21,12 +21,12 @@
 
 #include "prefs.h"
 
-#include <klocale.h>
-
 #include <QHBoxLayout>
 #include <QGridLayout>
 #include <QDebug>
 
+#include <KLocalizedString>
+
 LegendWidget::LegendWidget(QWidget *parent) : QWidget(parent)
 {
     m_update = true;
